@@ -237,3 +237,24 @@ def dict2list(data: dict, data_key="count", key_name="key", value_name="value"):
 class ReadOnlyDict(dict):
     def __setitem__(self, key, value):
         raise NotImplementedError("Dictionary is read-only")
+
+
+def sort_dfs(data, sort_key="serial_index", children_key="children"):
+    if data:
+        if isinstance(data, list):
+            # 使用lambda表达式获取sort_key的值，默认为0
+            # 使用或运算符（or）来处理None或其他假值的情况
+            data.sort(key=lambda item: item.get(sort_key, 0))
+
+            # 递归排序子元素
+            for element in data:
+                if isinstance(element, dict) and children_key in element:
+                    sort_dfs(element[children_key], sort_key=sort_key, children_key=children_key)
+        elif isinstance(data, dict):
+            if children_key in data:
+                # 排序字典中的子列表
+                data[children_key].sort(key=lambda item: item.get(sort_key, 0))
+
+                # 递归排序子元素
+                for sub_element in data[children_key]:
+                    sort_dfs(sub_element, sort_key=sort_key, children_key=children_key)
